==> information-system-model-3.0.0-20200211.095518-2-sources.jar: org/gcube/informationsystem/types/reference/properties/PropertyDefinition.java <==
package org.gcube.informationsystem.types.reference.properties;

import org.gcube.informationsystem.base.reference.properties.PropertyElement;
import org.gcube.informationsystem.types.annotations.ISProperty;
import org.gcube.informationsystem.types.impl.properties.PropertyDefinitionImpl;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;

/**
 * @author Luca Frosini (ISTI - CNR)
 * https://wiki.gcube-system.org/gcube/Facet_Based_Resource_Model#Header
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonDeserialize(as = PropertyDefinitionImpl.class)
public interface PropertyDefinition extends PropertyElement {
	
	public static final String NAME = "PropertyDefinition"; // PropertyDefinition.class.getSimpleName();
	
	public static final String NAME_PROPERTY = "name";
	public static final String DESCRIPTION_PROPERTY = "description";
	public static final String MANDATORY_PROPERTY = "mandatory";
	public static final String READ_ONLY_PROPERTY = "readonly";
	public static final String NOT_NULL_PROPERTY = "notnull";
	public static final String MAX_PROPERTY = "max";
	public static final String MIN_PROPERTY = "min";
	public static final String REGEX_PROPERTY = "regexp";
	public static final String LINKED_TYPE_PROPERTY = "linkedType";
	public static final String LINKED_CLASS_PROPERTY = "linkedClass";
	public static final String TYPE_PROPERTY = "type";
	
	@ISProperty(name = NAME_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public String getName();
	
	@ISProperty(name = DESCRIPTION_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getDescription();
	
	@ISProperty(name = MANDATORY_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isMandatory();
	
	@ISProperty(name = READ_ONLY_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isReadonly();
	
	@ISProperty(name = NOT_NULL_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isNotnull();
	
	@ISProperty(name = MAX_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getMax();
	
	@ISProperty(name = MIN_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getMin();
	
	@ISProperty(name = REGEX_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getRegexp();
	
	@ISProperty(name = LINKED_TYPE_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getLinkedType();
	
	@ISProperty(name = LINKED_CLASS_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getLinkedClass();
	
	@ISProperty(name = TYPE_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getType();
	
}

==> information-system-model-4.1.0-20201124.084053-7-sources.jar: org/gcube/informationsystem/types/reference/properties/PropertyDefinition.java <==
package org.gcube.informationsystem.types.reference.properties;

import org.gcube.com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import org.gcube.com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import org.gcube.informationsystem.base.reference.properties.PropertyElement;
import org.gcube.informationsystem.types.annotations.ISProperty;
import org.gcube.informationsystem.types.impl.properties.PropertyDefinitionImpl;

/**
 * @author Luca Frosini (ISTI - CNR)
 * https://wiki.gcube-system.org/gcube/Facet_Based_Resource_Model#Header
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonDeserialize(as = PropertyDefinitionImpl.class)
public interface PropertyDefinition extends PropertyElement {
	
	public static final String NAME = "PropertyDefinition"; // PropertyDefinition.class.getSimpleName();
	
	public static final String NAME_PROPERTY = "name";
	public static final String DESCRIPTION_PROPERTY = "description";
	public static final String MANDATORY_PROPERTY = "mandatory";
	public static final String READ_ONLY_PROPERTY = "readonly";
	public static final String NOT_NULL_PROPERTY = "notnull";
	public static final String MAX_PROPERTY = "max";
	public static final String MIN_PROPERTY = "min";
	public static final String REGEX_PROPERTY = "regexp";
	public static final String LINKED_TYPE_PROPERTY = "linkedType";
	public static final String LINKED_CLASS_PROPERTY = "linkedClass";
	public static final String TYPE_PROPERTY = "type";
	
	@ISProperty(name = NAME_PROPERTY, readonly = true, mandatory = true, nullable = false)
	public String getName();
	
	@ISProperty(name = DESCRIPTION_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getDescription();
	
	@ISProperty(name = MANDATORY_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isMandatory();
	
	@ISProperty(name = READ_ONLY_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isReadonly();
	
	@ISProperty(name = NOT_NULL_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public boolean isNotnull();
	
	@ISProperty(name = MAX_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getMax();
	
	@ISProperty(name = MIN_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getMin();
	
	@ISProperty(name = REGEX_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getRegexp();
	
	@ISProperty(name = LINKED_TYPE_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getLinkedType();
	
	@ISProperty(name = LINKED_CLASS_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public String getLinkedClass();
	
	@ISProperty(name = TYPE_PROPERTY, readonly = false, mandatory = true, nullable = false)
	public Integer getType();
	
}
